==> 0.1.2-beta.tar.gz: lib/src/dom/mediacapture_automation.dart <==
// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:js_interop';

typedef MockCapturePromptResult = JSString;

@JS()
@staticInterop
@anonymous
class MockCapturePromptResultConfiguration implements JSObject {
  external factory MockCapturePromptResultConfiguration({
    MockCapturePromptResult getUserMedia,
    MockCapturePromptResult getDisplayMedia,
  });
}

extension MockCapturePromptResultConfigurationExtension
    on MockCapturePromptResultConfiguration {
  external set getUserMedia(MockCapturePromptResult value);
  external MockCapturePromptResult get getUserMedia;
  external set getDisplayMedia(MockCapturePromptResult value);
  external MockCapturePromptResult get getDisplayMedia;
}

@JS()
@staticInterop
@anonymous
class MockCaptureDeviceConfiguration implements JSObject {
  external factory MockCaptureDeviceConfiguration({
    JSString label,
    JSString deviceId,
    JSString groupId,
  });
}

extension MockCaptureDeviceConfigurationExtension
    on MockCaptureDeviceConfiguration {
  external set label(JSString value);
  external JSString get label;
  external set deviceId(JSString value);
  external JSString get deviceId;
  external set groupId(JSString value);
  external JSString get groupId;
}

@JS()
@staticInterop
@anonymous
class MockCameraConfiguration implements MockCaptureDeviceConfiguration {
  external factory MockCameraConfiguration({
    JSNumber defaultFrameRate,
    JSString facingMode,
  });
}

extension MockCameraConfigurationExtension on MockCameraConfiguration {
  external set defaultFrameRate(JSNumber value);
  external JSNumber get defaultFrameRate;
  external set facingMode(JSString value);
  external JSString get facingMode;
}

@JS()
@staticInterop
@anonymous
class MockMicrophoneConfiguration implements MockCaptureDeviceConfiguration {
  external factory MockMicrophoneConfiguration({JSNumber defaultSampleRate});
}

extension MockMicrophoneConfigurationExtension on MockMicrophoneConfiguration {
  external set defaultSampleRate(JSNumber value);
  external JSNumber get defaultSampleRate;
}

==> 0.2.2-beta.tar.gz: lib/src/dom/mediacapture_automation.dart <==
// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:js_interop';

typedef MockCapturePromptResult = String;

@JS()
@staticInterop
@anonymous
class MockCapturePromptResultConfiguration implements JSObject {
  external factory MockCapturePromptResultConfiguration({
    MockCapturePromptResult getUserMedia,
    MockCapturePromptResult getDisplayMedia,
  });
}

extension MockCapturePromptResultConfigurationExtension
    on MockCapturePromptResultConfiguration {
  external set getUserMedia(MockCapturePromptResult value);
  external MockCapturePromptResult get getUserMedia;
  external set getDisplayMedia(MockCapturePromptResult value);
  external MockCapturePromptResult get getDisplayMedia;
}

@JS()
@staticInterop
@anonymous
class MockCaptureDeviceConfiguration implements JSObject {
  external factory MockCaptureDeviceConfiguration({
    String label,
    String deviceId,
    String groupId,
  });
}

extension MockCaptureDeviceConfigurationExtension
    on MockCaptureDeviceConfiguration {
  external set label(String value);
  external String get label;
  external set deviceId(String value);
  external String get deviceId;
  external set groupId(String value);
  external String get groupId;
}

@JS()
@staticInterop
@anonymous
class MockCameraConfiguration implements MockCaptureDeviceConfiguration {
  external factory MockCameraConfiguration({
    double defaultFrameRate,
    String facingMode,
  });
}

extension MockCameraConfigurationExtension on MockCameraConfiguration {
  external set defaultFrameRate(double value);
  external double get defaultFrameRate;
  external set facingMode(String value);
  external String get facingMode;
}

@JS()
@staticInterop
@anonymous
class MockMicrophoneConfiguration implements MockCaptureDeviceConfiguration {
  external factory MockMicrophoneConfiguration({int defaultSampleRate});
}

extension MockMicrophoneConfigurationExtension on MockMicrophoneConfiguration {
  external set defaultSampleRate(int value);
  external int get defaultSampleRate;
}
